<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Basisklasse für Baum-Knoten und Bäume.
 *
 * @package GhCore
 * @subpackage tree
 * @category Hilfsklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
abstract class GhCoreTreeBase
{
  /**
   * Kind-Knoten.
   * Bei einem Baum-Knoten sind dies die Kind-Knoten, bei einem Baum die Wurzel-Knoten.
   * @var array
   */
  protected $_children = array();

  /**
   * Liefert die Kind-Knoten dieses Knoten/Baumes.
   *
   * @return array Kind-Knoten
   */
  public function getChildren()
  {
    return $this->_children;
  }

  /**
   * Fügt einen neuen Knoten zu diesem Baum-Knoten oder Baum hinzu.
   *
   * @param int|string $id      ID des neuen Knotens
   * @param string     $caption Titel des neuen Knotens
   * @param mixed      $data    Daten des neuen Knotens
   * @return GhCoreTreeNode Der neu hinzugefügte Knoten
   */
  abstract public function add($id, $caption, $data = null);
}
