<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * WYSIWYG Editor.
 * 
 * @package GhGui
 * @subpackage component
 * @category PHP-GUI-Einzelkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiEditor extends GhGuiFormComponent
{
  /**
   * Editor-Plugin für ein Trennelement in der Toolbar des Editors.
   * @var const
   */
  const PLUGIN_TOOLBAR_SEPARATOR = '-';

  /**
   * Editor-Plugin für einen Umbruch in der Toolbar des Editors.
   * @var const
   */
  const PLUGIN_TOOLBAR_LINEBREAK = '/';

  /**
   * Editor-Plugin für die Rückgängig-Funktion.
   * @var const
   */
  const PLUGIN_UNDO = 'Undo';

  /**
   * Editor-Plugin für die Wiederherstellen-Funktion.
   * @var const
   */
  const PLUGIN_REDO = 'Redo';

  /**
   * Editor-Plugin für die das Ausschneiden von Inhalten.
   * @var const
   */
  const PLUGIN_CUT = 'Cut';

  /**
   * Editor-Plugin für das Kopieren von Inhalten.
   * @var const
   */
  const PLUGIN_COPY = 'Copy';

  /**
   * Editor-Plugin für Einfügen von Inhalten.
   * @var const
   */
  const PLUGIN_PASTE = 'Paste';

  /**
   * Editor-Plugin für Löschen von Inhalten.
   * @var const
   */
  const PLUGIN_DELETE = 'Delete';

  /**
   * Editor-Plugin für Fettdruck.
   * @var const
   */
  const PLUGIN_BOLD = 'Bold';

  /**
   * Editor-Plugin für Kursivdruck.
   * @var const
   */
  const PLUGIN_ITALIC = 'Italic';

  /**
   * Editor-Plugin für Unterstreichen.
   * @var const
   */
  const PLUGIN_UNDERLINE = 'Underline';

  /**
   * Editor-Plugin für Durchstreichen.
   * @var const
   */
  const PLUGIN_STRIKETHROUGH = 'Strike';

  /**
   * Editor-Plugin für das Einfügen einer sortierten Liste.
   * @var const
   */
  const PLUGIN_INSERT_ORDERED_LIST = 'NumberedList';

  /**
   * Editor-Plugin für das Einfügen einer unsortierten Liste.
   * @var const
   */
  const PLUGIN_INSERT_UNORDERED_LIST = 'BulletedList';

  /**
   * Editor-Plugin für Einrücken.
   * @var const
   */
  const PLUGIN_INDENT = 'Indent';

  /**
   * Editor-Plugin für Ausrücken.
   * @var const
   */
  const PLUGIN_OUTDENT = 'Outdent';

  /**
   * Editor-Plugin für linksbündige Ausrichtung.
   * @var const
   */
  const PLUGIN_JUSTIFY_LEFT = 'JustifyLeft';

  /**
   * Editor-Plugin für zentrierte Ausrichtung.
   * @var const
   */
  const PLUGIN_JUSTIFY_CENTER = 'JustifyCenter';

  /**
   * Editor-Plugin für rechtsbündige Ausrichtung.
   * @var const
   */
  const PLUGIN_JUSTIFY_RIGHT = 'JustifyRight';

  /**
   * Editor-Plugin für Blocksatz.
   * @var const
   */
  const PLUGIN_JUSTIFY_FULL = 'JustifyBlock';

  /**
   * Editor-Plugin für das Wählen der Textfarbe.
   * @var const
   */
  const PLUGIN_TEXT_COLOR = 'TextColor';

  /**
   * Editor-Plugin für das Wählen der Hintergrundfarbe.
   * @var const
   */
  const PLUGIN_BACKGROUND_COLOR = 'BGColor';

  /**
   * Editor-Plugin für die Schriftartauswahl.
   * @var const
   */
  const PLUGIN_FONT_NAME = 'Font';

  /**
   * Editor-Plugin für Schriftgrößenauswahl.
   * @var const
   */
  const PLUGIN_FONT_SIZE = 'FontSize';

  /**
   * Editor-Plugin für das Schriftformat.
   * @var const
   */
  const PLUGIN_FONT_FORMAT = 'Format';

  /**
   * Editor-Plugin für das Erstellen eines Links.
   * @var const
   */
  const PLUGIN_INSERT_LINK = 'Link';

  /**
   * Editor-Plugin für das Einfügen eines Bildes.
   * @var const
   */
  const PLUGIN_INSERT_IMAGE = 'Image';

  /**
   * Editor-Plugin für das Einfügen von Inline-Bildern.
   * @var const
   */
  const PLUGIN_INSERT_INLINE_IMAGE = 'inlineImage';

  /**
   * Editor-Plugin für das Einfügen eines Emoticon ("Smiley").
   * @var const
   */
  const PLUGIN_INSERT_EMOTICON = 'Smiley';

  /**
   * Editor-Plugin für Drucken.
   * @var const
   */
  const PLUGIN_PRINT = 'Print';

  /**
   * Editor-Plugin für Zitate.
   * @var const
   */
  const PLUGIN_BLOCKQUOTE = 'Blockquote';

  /**
   * Editor-Plugin für eine Vorschau.
   * @var const
   */
  const PLUGIN_PREVIEW = 'Preview';

  /**
   * Editor-Plugin zum Auswählen des gesamten Inhalts.
   * @var const
   */
  const PLUGIN_SELECT_ALL = 'SelectAll';

  /**
   * Editor-Plugin für tiefer gestellten Text.
   */
  const PLUGIN_SUBSCRIPT = 'Subscript';

  /**
   * Editor-Plugin für höher gestellten Text.
   */
  const PLUGIN_SUPERSCRIPT = 'Superscript';

  /**
   * Editor-Plugin für das Anzeigen des Quelltexts.
   * @var const
   */
  const PLUGIN_VIEW_SOURCE = 'Source';

  /**
   * Editor-Plugin für Suchen und Ersetzen.
   * @var const
   */
  const PLUGIN_FIND = 'Find';

  /**
   * Editor-Plugin für Suchen und Ersetzen.
   * @var const
   */
  const PLUGIN_FIND_REPLACE = 'Replace';

  /**
   * Editor-Plugin für das Leeren der Seite.
   * @var const
   */
  const PLUGIN_NEW_PAGE = 'NewPage';

  /**
   * Editor-Plugin für den Vollbildmodus.
   * @var const
   */
  const PLUGIN_FULLSCREEN = 'Maximize';

  /**
   * Widget Klassenname dieser Komponente.
   * @var string
   */
  protected $_widgetClass = 'greyhound.dojo.Editor';

  /**
   * Events, die ein automatisches Absenden des Formulars auslösen.
   * @var array
   */
  protected $_autoSubmitEvents = array('onChange');

  /**
   * Legt fest, ob die Attribute 'name' und 'value' für den HTML-Knoten erzeugt
   * werden.
   * @var boolean
   */
  protected $_createNameAndValueAttributes = false;

  /**
   * Legt fest, ob die Eigenschaften 'name' und 'value' für das Javascript
   * Widget erzeugt werden.
   * @var boolean
   */
  protected $_createNameAndValueWidgetProperties = false;

  /**
   * ID des (versteckten) Formularfeldes, das den Wert der Auswahl aufnimmt.
   * @var string
   */
  protected $_hiddenFieldId;

  /**
   * Konstruktor.
   *
   * Optional kann der Name des Eingabefeldes (siehe setName()) und der
   * Vorgabeinhalt (siehe setDefaultValue()) festgelegt werden. Zusätzlich
   * können die Möglichkeiten des Editors eingestellt werden, indem die
   * Editor-Plugins angegeben werden, die zur Verfügung stehen sollen.
   *
   * @param string  $name         Name des Formularfeldes
   * @param string  $defaultValue Vorgabeinhalt für das Formularfeld
   * @param array   $plugins      Editor-Plugins
   */
  public function __construct($name = null, $defaultValue = null, array $plugins = null)
  {
    parent::__construct($name, null, $defaultValue);
    $this->addClass('GhGuiEditor');
    $this->_hiddenFieldId = GhGui::createId();
    $this->setWidgetProperty('textAreaId', $this->_hiddenFieldId);
    $this->setWidgetProperty('config', array(
      'language' => 'de',
      'extraPlugins' => 'docprops'
    ));

    if($plugins !== null)
      $this->setPlugins($plugins);
    else
      $this->setPlugins(
        array(
          GhGuiEditor::PLUGIN_UNDO, GhGuiEditor::PLUGIN_REDO,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_SELECT_ALL,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_CUT, GhGuiEditor::PLUGIN_COPY, GhGuiEditor::PLUGIN_PASTE,
          /*
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_DELETE,
          */
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_FIND, GhGuiEditor::PLUGIN_FIND_REPLACE,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_INSERT_INLINE_IMAGE, GhGuiEditor::PLUGIN_INSERT_LINK,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_VIEW_SOURCE,
          GhGuiEditor::PLUGIN_FULLSCREEN,
          GhGuiEditor::PLUGIN_PREVIEW,
          GhGuiEditor::PLUGIN_TOOLBAR_LINEBREAK,
          GhGuiEditor::PLUGIN_FONT_NAME, GhGuiEditor::PLUGIN_FONT_SIZE,
          GhGuiEditor::PLUGIN_BOLD, GhGuiEditor::PLUGIN_ITALIC, GhGuiEditor::PLUGIN_UNDERLINE, GhGuiEditor::PLUGIN_STRIKETHROUGH,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_JUSTIFY_LEFT, GhGuiEditor::PLUGIN_JUSTIFY_CENTER, GhGuiEditor::PLUGIN_JUSTIFY_RIGHT, GhGuiEditor::PLUGIN_JUSTIFY_FULL,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_SUBSCRIPT, GhGuiEditor::PLUGIN_SUPERSCRIPT,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_INSERT_ORDERED_LIST, GhGuiEditor::PLUGIN_INSERT_UNORDERED_LIST,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_OUTDENT, GhGuiEditor::PLUGIN_INDENT,
          GhGuiEditor::PLUGIN_TOOLBAR_SEPARATOR,
          GhGuiEditor::PLUGIN_TEXT_COLOR, GhGuiEditor::PLUGIN_BACKGROUND_COLOR
        )
      );
  }

  /**
   * Fügt Editor-Plugins hinzu.
   *
   * Als Parameter kann entweder ein Array mit Editor-Plugins übergeben werden,
   * oder mehrere Editor-Plugins als einzelne Parameter.
   *
   * @param string|array $plugins    Editor-Plugins
   * @param string       $plugins... weitere Editor-Plugins
   * @return GhGuiEditor liefert die Komponente zurück um verkettete Aufrufe zu ermöglichen
   */
  public function addPlugins($plugins)
  {
    if(!is_array($plugins))
      $plugins = array($plugins);

    for($i = 1; $i < func_num_args(); $i++)
      $plugins[] = func_get_arg($i);

    $plugins = array_merge($this->getPlugins(), $plugins);
    $this->setPlugins($plugins);

    return $this;
  }

  /**
   * Entfernt Editor-Plugins.
   * 
   * Als Parameter kann entweder ein Array mit Editor-Plugins übergeben werden,
   * oder mehrere Editor-Plugins als einzelne Parameter.
   *
   * @param string|array $plugins    Editor-Plugins
   * @param string       $plugins... weitere Editor-Plugins
   * @return GhGuiEditor liefert die Komponente zurück um verkettete Aufrufe zu ermöglichen
   */
  public function removePlugins($plugins)
  {
    if(!is_array($plugins))
      $plugins = array($plugins);

    for($i = 1; $i < func_num_args(); $i++)
      $plugins[] = func_get_arg($i);

    $currentPlugins = $this->getPlugins();

    foreach($plugins as $plugin)
    {
      $index = array_search($plugin, $currentPlugins);

      if($index !== false)
        unset($currentPlugins[$index]);
    }

    $this->setPlugins($currentPlugins);

    return $this;
  }

  /**
   * Legt die zur Verfügung stehenden Editor-Plugins fest.
   *
   * Als Parameter kann entweder ein Array mit Editor-Plugins übergeben werden,
   * oder mehrere Editor-Plugins als einzelne Parameter.
   *
   * @param string|array $plugins    Editor-Plugins
   * @param string       $plugins... weitere Editor-Plugins
   * @return GhGuiEditor liefert die Komponente zurück um verkettete Aufrufe zu ermöglichen
   */
  public function setPlugins($plugins)
  {
    if(!is_array($plugins))
      $plugins = array($plugins);

    for($i = 1; $i < func_num_args(); $i++)
      $plugins[] = func_get_arg($i);

    $line = array();
    $allPlugins = array();

    foreach($plugins as $plugin)
    {
      if($plugin == GhGuiEditor::PLUGIN_TOOLBAR_LINEBREAK)
      {
        if(!empty($allPlugins))
          $allPlugins[] = GhGuiEditor::PLUGIN_TOOLBAR_LINEBREAK;

        $allPlugins[] = $line;
        $line = array();
      }
      else
        $line[] = $plugin;
    }

    if(!empty($line))
    {
      if(!empty($allPlugins))
        $allPlugins[] = GhGuiEditor::PLUGIN_TOOLBAR_LINEBREAK;

      $allPlugins[] = $line;
    }

    $this->setWidgetProperty('toolbar', $allPlugins);

    return $this;
  }

  /**
   * Liefert die Editor-Plugins die der Editor zur Verfügung stellt.
   *
   * @return array
   */
  public function getPlugins()
  {
    $plugins = $this->getWidgetProperty('toolbar');

    if(!is_array($plugins))
      return $plugins;

    $allPlugins = array();

    foreach($plugins as $plugin)
    {
      if(is_array($plugin))
        $allPlugins = array_merge($allPlugins, $plugin);
      else
        $allPlugins[] = $plugin;
    }

    return $allPlugins;
  }

  /**
   * Liefert die ID des versteckten Formularfeldes, das den Wert der Auswahl
   * aufnimmt.
   *
   * @return string
   */
  public function getValueNodeId()
  {
    return $this->_hiddenFieldId;
  }

  /**
   * Liefert zusätzliche, von dieser Komponente benötigte Javascript URLs.
   *
   * @return array
   */
  protected function _getRequiredJavascriptUrls()
  {
    $urls = parent::_getRequiredJavascriptUrls();

    if(!is_array($urls))
      $urls = array();

    $urls[] = 'ghgui://lib/ckeditor/ckeditor.js';

    return $urls;
  }

  /**
   * Liefert den HTML Code für diese Komponente.
   *
   * @return string
   */
  protected function _getHtml()
  {
    if(!$this->_htmlTag)
      return '';

    $editorAttributes = array(
      'id' => $this->_hiddenFieldId
    );

    if($this->getName())
      $editorAttributes['name'] = $this->getName();

    return GhGui::createHtml($this->_htmlTag, $this->_getAllAttributes(), GhGui::createHtml('textarea', $editorAttributes, htmlspecialchars($this->getValue())));
  }

  /**
   * Initialisiert die Komponente für das Abrufen des HTML-Codes.
   *
   * Liefert true, falls die Komponente initialisiert wurde, false, falls die
   * Komponente bereits initialisiert war.
   *
   * @return boolean
   */
  protected function _initHtml()
  {
    if(!parent::_initHtml())
      return false;

    $this->setWidgetProperty('ghGuiBaseUrl', GhGui::getBaseUrl());

    $properties = parent::getWidgetProperties();

    // Externe Plugins einbinden:
    $plugins = $this->getPlugins();

    $externalPlugins = array();

    foreach($plugins as $plugin)
    {
      if($plugin == GhGuiEditor::PLUGIN_INSERT_INLINE_IMAGE)
        $externalPlugins['inlineimage'] = array('inlineimage', GhGui::createUrl('ghgui://lib/greyhound/ckeditor/plugins/inlineimage/', 'plugin.js'));
    }

    // Zusätzliche externe Plugins hinzufügen:
    if(!empty($externalPlugins))
    {
      if(isset($properties['config']))
        $config = $properties['config'];
      else
        $config = array();

      $existingExternalPlugins = array();

      if(!isset($properties['externalPlugins']))
        $properties['externalPlugins'] = array();
      else
        foreach($properties['externalPlugins'] as $plugin)
          $existingExternalPlugins[] = $plugin[2];

      foreach($externalPlugins as $pluginName => $pluginDefinition)
      {
        if(!in_array($pluginName, $existingExternalPlugins))
        {
          $properties['externalPlugins'][] = $pluginDefinition;
          $existingExternalPlugins[] = $pluginName;
        }
      }

      if(isset($config['extraPlugins']))
        $extraPlugins = explode(',', $config['extraPlugins']);
      else
        $extraPlugins = array();

      foreach(array_keys($externalPlugins) as $pluginName)
        if(!in_array($pluginName, $extraPlugins))
          $extraPlugins[] = $pluginName;

      $config['extraPlugins'] = implode(',', $extraPlugins);

      $this->setWidgetProperty('externalPlugins', $properties['externalPlugins']);
      $this->setWidgetProperty('config', $config);
    }

    return true;
  }

  /**
   * Liefert den Datentyp, den eine bestimmte Widget-Eigenschaft haben muss.
   *
   * @param string $property Eigenschaft
   * @return string
   */
  protected function __getWidgetPropertyType($property)
  {
    switch($property)
    {
      case 'toolbar':
      case 'externalPlugins':
        return 'array';

      case 'config':
        return 'object';
    }

    return parent::__getWidgetPropertyType($property);
  }
}