<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Verstecktes Formularfeld.
 *
 * @package GhGui
 * @subpackage component
 * @category PHP-GUI-Einzelkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiHiddenField extends GhGuiFormComponent
{
  /**
   * Name/Typ des HTML-Knotens der für diese Komponente erzeugt wird.
   * @var string
   */
  protected $_htmlTag = 'input';

  /**
   * Attribute für den Haupt-DOM-Knoten dieser Komponente.
   * @var array
   */
  protected $_attributes = array('type' => 'hidden');

  /**
   * Vorgegebener HTML Code für dieses versteckte Formularfeld.
   * @var string
   */
  protected $_html;

  /**
   * Konstruktor.
   *
   * Optional kann der Name, der Wert und die ID für das versteckte
   * Formularfeld angegeben werden.
   *
   * Normalerweise wird der HTML Code generiert, aber für spezielle
   * Anforderungen (z.B. select- statt input-Elemente) kann der komplette HTML
   * Code für das Feld vorgegeben werden.
   *
   * @param string $name  Feldname
   * @param string $value Wert
   * @param string $id    ID
   * @param string $html  HTML Code für das Formularfeld
   */
  public function __construct($name = null, $value = null, $id = null, $html = null)
  {
    parent::__construct($name, $value);

    if($id !== null)
      $this->setId($id);

    if($html !== null)
      $this->_html = $html;
  }

  /**
   * Liefert den HTML Code für diese Komponente.
   *
   * @return string
   */
  protected function _getHtml()
  {
    if($this->_html)
      return $this->_html;
    else
      return parent::_getHtml();
  }

  /**
   * Liefert den Javascript Code für diese Komponente.
   *
   * @return string
   */
  protected function _getJavascript()
  {
    return 'var ' . $this->getJavascriptWidgetVariable() . '=dojo.byId("' . $this->getId() . '");' . GhGui::$eol;
  }
}
