<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * IFrame Komponente.
 *
 * @package GhGui
 * @subpackage component
 * @category PHP-GUI-Einzelkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiIframe extends GhGuiComponent
{
  /**
   * Name/Typ des HTML-Knotens der für diese Komponente erzeugt wird.
   * @var string
   */
  protected $_htmlTag = 'iframe';

  /**
   * Attribute für den Haupt-DOM-Knoten dieser Komponente.
   * @var array
   */
  protected $_attributes = array(
    'frameborder' => '0',
    'marginwidth' => '0',
    'marginheight' => '0',
    'hspace' => '0',
    'vspace' => '0',
    'scrolling' => 'no'
  );

  /**
   * Widget Klassenname dieser Komponente.
   * @var string
   */
  protected $_widgetClass = 'greyhound.dojo.Iframe';

  /**
   * CSS Klassen für den Haupt-DOM-Knoten dieser Komponente.
   * @var array
   */
  protected $_classes = array('GhGuiIframe');

  /**
   * CSS Angaben für den Haupt-DOM-Knoten dieser Komponente.
   * Diese Angaben werden als 'style' Attribut bei der Ausgabe des HTML-Codes
   * den Attributen der Komponente hinzugefügt.
   *
   * Das IFrame verwendet standardmäßig die gesamte Breite und Höhe die ihm zur
   * Verfügung steht. Außerdem wird das IFrame absolut am unteren Rand
   * positioniert, da sonst Layout-Probleme auftreten (das IFrame ist einige
   * Pixel versetzt und es erscheint eine Scrollbar).
   *
   * @var array
   */
  protected $_styles = array('border' => '0px', 'margin' => '0px', 'padding' => '0px', 'display' => 'block');

  /**
   * URL des IFrame-Inhalts.
   * @var string
   */
  protected $_url;

  /**
   * Konstruktor.
   *
   * Optional kann die URL des IFrame-Inhalts angegeben werden.
   *
   * @param string $url URL des IFrame-Inhalts.
   */
  public function __construct($url = null)
  {
    parent::__construct();

    if($url !== null)
      $this->setUrl($url);
  }

  /**
   * Setzt die URL des IFrame-Inhalts.
   *
   * @param string $url URL
   * @return GhGuiIframe liefert die Komponente zurück um verkettete Aufrufe zu ermöglichen
   */
  public function setUrl($url)
  {
    $this->setWidgetProperty('url', $url);

    return $this;
  }

  /**
   * Liefert die URL des IFrame-Inhalts.
   *
   * @return string
   */
  public function getUrl()
  {
    return $this->getWidgetProperty('url');
  }

  /**
   * Liefert den HTML Code für diese Komponente.
   *
   * @return string
   */
  protected function _getHtml()
  {
    $attributes = $this->_getAllAttributes();
    $attributes['name'] = $this->getId();

    //if ($this->_url)
    //  $attributes['src'] = $this->_url;

    return GhGui::createHtml($this->_htmlTag, $attributes);
  }
}