<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Passwort Komponente (Text-Box mit Passwort-Option).
 *
 * Dies ist ein einzeiliges Textfeld das die eingegebenen Zeichen maskiert
 * darstellt und zur Eingabe von Passworten dient.
 *
 * Normale einzeilige Textfelder können durch die
 * [classes]GhGuiTextBox[/classes] Komponente dargestellt werden.
 *
 * @package GhGui
 * @subpackage component
 * @category PHP-GUI-Einzelkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiPasswordBox extends GhGuiTextBox
{
  /**
   * Attribute für den Haupt-DOM-Knoten dieser Komponente.
   * @var array
   */
  protected $_attributes = array('type' => 'password');

  /**
   * Konstruktor.
   *
   * Optional kann der Name des Eingabefeldes (siehe setName()) und der
   * Vorgabewert (siehe setDefaultValue()) festgelegt werden.
   *
   * @param string  $name         Name des Formularfeldes
   * @param string  $defaultValue Vorgabewert für das Formularfeld
   */
  public function __construct($name = null, $defaultValue = null)
  {
    parent::__construct($name, $defaultValue);
    $this->setWidgetProperty('type', 'password');
  }
}
