<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Einfacher Container.
 * Dieser Container gibt seine Komponenten ohne weitere Layoutvorgaben
 * hintereinander aus.
 *
 * @package GhGui
 * @subpackage container
 * @category PHP-GUI-Strukturkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiPanel extends GhGuiContainer
{
  /**
   * Widget Klassenname dieser Komponente.
   * @var string
   */
  protected $_widgetClass = 'dijit.layout.ContentPane';

  /**
   * Liste der Komponenten dieses Containers.
   * @var array
   */
  protected $_components = array();

  /**
   * Konstruktor.
   *
   * Optional können ein oder mehrere Komponenten angegeben werden, die zu
   * diesem Container hinzugefügt werden.
   *
   * @param GhGuiComponent $component    Komponente
   * @param GhGuiComponent $component... weitere Komponenten
   */
  public function __construct(GhGuiComponent $component = null)
  {
    parent::__construct();

    if($component !== null)
      $this->addComponent($component);
    for($i = 1; $i < func_num_args(); $i++)
      $this->addComponent(func_get_arg($i));
  }

  /**
   * Fügt eine Komponente hinzu.
   *
   * @param GhGuiComponent $component Komponente
   * @return GhGuiComponent liefert die hinzugefügte Komponente zurück
   */
  public function addComponent(GhGuiComponent $component)
  {
    $component->_setParentContainer($this);
    $this->_components[] = $component;

    return $component;
  }

  /**
   * Entfernt eine Komponente.
   *
   * @param GhGuiComponent $component Komponente
   * @return GhGuiPanel liefert das GhGuiPanel zurück um verkettete Aufrufe zu ermöglichen
   */
  public function removeComponent(GhGuiComponent $component)
  {
    $id = $component->getId();
    foreach($this->_components as $key => $tmpComponent)
    {
      if($tmpComponent == $id)
        unset($this->_components[$key]);
    }

    return $this;
  }

  /**
   * Entfernt alle Komponenten dieses Containers.
   *
   * @return GhGuiPanel liefert das GhGuiPanel zurück um verkettete Aufrufe zu ermöglichen
   */
  public function removeComponents()
  {
    $this->_components = array();

    return $this;
  }

  /**
   * Liefert die in diesem Container enthaltenen Komponenten.
   *
   * @return array
   */
  public function getComponents()
  {
    return $this->_components;
  }

  /**
   * Liefert alle in diesem Container enthaltenen Komponenten.
   *
   * @return array
   */
  protected function _getAllComponents()
  {
    return $this->getComponents();
  }
}