<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Event-Handler, der beliebigen Javascript Code ausführt.
 *
 * @package GhGui
 * @subpackage event
 * @category PHP-GUI-Event-Handler
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiEventJavascript extends GhGuiEvent
{
  /**
   * Javascript Code, der durch den Event-Handler ausgeführt wird.
   * @var string
   */
  protected $_javascript;

  /**
   * Konstruktor.
   *
   * Dem Konstruktor muss der Javascript Code übergeben werden, der durch den
   * Event-Handler ausgeführt werden soll.
   *
   * Der Javascript-Code muss folgendem Format entsprechen:
   * 'function(event){...}'.
   *
   * @param string         $javascript Javascript Code
   */
  public function __construct($javascript)
  {
    parent::__construct();

    $this->_javascript = $javascript;
  }

  /**
   * Liefert den Javascript Code für die Event-Hanlder Javascript-Funktion.
   *
   * @param GhGuiComponent $source Komponente, auf der das Event registriert werden soll
   * @param string         $event  Event-Name
   * @return string
   */
  public function getJavascriptFunction(GhGuiComponent $source, $event)
  {
    return $this->_javascript;
  }
}