<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Webseitenkomponente für die Vorschauzeile in Client Erweiterungen.
 *
 * Diese Webseite verwendet dieselbe Hintergrundfarbe wie die Vorschauzeilen im
 * GREYHOUND Client und stellt die Komponenten im Stil des Clients dar um eine
 * möglichst nahtlose visuelle Integration in den Client zu ermöglichen.
 *
 * Styles und Attribute, die auf der Webseitenkomponente gesetzt werden,
 * werden auf den 'body' Knoten der Webseite angewendet.
 *
 * @package GhGui
 * @subpackage page
 * @category PHP-GUI-Webseitenkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiExtensionPreviewLinePage extends GhGuiExtensionPage
{
  /**
   * Konstruktor.
   *
   * Optional kann der Titel der Webseite (für den 'title' Knoten) und die
   * Basis-URL der Webseite angegeben werden.
   *
   * @param string $title   Titel der Webseite
   * @param string $baseUrl Basis-URL der Webseite
   */
  public function __construct($title = null, $baseUrl = null)
  {
    parent::__construct($title, $baseUrl);

    $this->_splashScreenStyles['background'] = '#afafaf';

    // Das Stylesheet der GhGuiExtensionPage gegen das dieser Seite austauschen:
    foreach($this->_stylesheets as $key => $stylesheet)
      if($stylesheet == 'ghgui://lib/greyhound/page/ghguiextensionpage/screen.css')
      {
        $this->_stylesheets[$key] = 'ghgui://lib/greyhound/page/ghguiextensionpreviewlinepage/screen.css';
        break;
      }

    $this->_pageWrapperId = GhGui::createId();
  }
}