<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_colorslib.
 *
 * @package GhRpc
 * @subpackage rpc_colorslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_colorslib extends GhRpcLibrary
{
  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsForbidden Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsForbidden = 1;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 2;
  /**
   * wsForeign Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsForeign = 3;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcColors.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcColorslibRpcColors
   */
  public static function newRpcColors(GhRpcClient $client)
  {
    return new GhRpcColorslibRpcColors($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcColorslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcColorslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcColor.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcColorslibRpcColor
   */
  public static function newRpcColor($fillProperties = false)
  {
    $object = new GhRpcColorslibRpcColor();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcColorList.
 *
 * @package GhRpc
 * @subpackage rpc_colorslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcColorslibRpcColor extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * CategoryRefs
   * @var array
   */
  public $CategoryRefs;

  /**
   * WorkSpace
   * @var int
   */
  public $WorkSpace;

  /**
   * Order
   * @var int
   */
  public $Order;

  /**
   * Code
   * @var int
   */
  public $Code;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * LockData
   * @var GhRpcColorslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'CategoryRefs' => 'array:int',
    'WorkSpace' => 'int',
    'Order' => 'int',
    'Code' => 'int',
    'Name' => 'string',
    'LockData' => 'GhRpcColorslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcColorList.
 *
 * @package GhRpc
 * @subpackage rpc_colorslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcColorslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcColors
 *
 * @package GhRpc
 * @subpackage rpc_colorslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcColorslibRpcColors extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcColorslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'SetOrder' => array(
      'params' => array(
        'ID' => 'int',
        'Order' => 'int',
      ),
      'return' => '',
    ),
    'AddCategory' => array(
      'params' => array(
        'ID' => 'int',
        'CategoryRef' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Color' => 'GhRpcColorslibRpcColor',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Color' => 'GhRpcColorslibRpcColor',
      ),
      'return' => 'int',
    ),
    'GetCompleteList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcColorslibRpcColor',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcColorslibRpcColor',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcColorslibRpcColor',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcColors.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcColorslibRpcColor
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcColors.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcColors.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.GetCompleteList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetCompleteList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcColors.GetCompleteList', array($AdvancedFields), self::$_rpcMethods['GetCompleteList']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcColorslibRpcColor $Color
   *
   * @return int
   */
  public function New_(GhRpcColorslibRpcColor $Color = null)
  {
    return $this->_sendRpcRequest('RpcColors.New', array($Color), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcColorslibRpcColor $Color
   */
  public function Put(GhRpcColorslibRpcColor $Color = null)
  {
    return $this->_sendRpcRequest('RpcColors.Put', array($Color), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcColors.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.AddCategory auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $CategoryRef
   */
  public function AddCategory($ID = 0, $CategoryRef = 0)
  {
    return $this->_sendRpcRequest('RpcColors.AddCategory', array($ID, $CategoryRef), self::$_rpcMethods['AddCategory']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.SetOrder auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Order
   */
  public function SetOrder($ID = 0, $Order = 0)
  {
    return $this->_sendRpcRequest('RpcColors.SetOrder', array($ID, $Order), self::$_rpcMethods['SetOrder']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcColors.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcColors.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcColors.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcColorslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcColors.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
