<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2022 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_groupslib.
 *
 * @package GhRpc
 * @subpackage rpc_groupslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_groupslib extends GhRpcLibrary
{
  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsForbidden Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsForbidden = 1;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 2;
  /**
   * wsShared Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsShared = 3;
  /**
   * wsForeign Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsForeign = 4;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcGroups.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcGroupslibRpcGroups
   */
  public static function newRpcGroups(GhRpcClient $client)
  {
    return new GhRpcGroupslibRpcGroups($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcGroupSignatures.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcGroupslibRpcGroupSignatures
   */
  public static function newRpcGroupSignatures($fillProperties = false)
  {
    $object = new GhRpcGroupslibRpcGroupSignatures();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcGroupslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcGroupslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcGroup.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcGroupslibRpcGroup
   */
  public static function newRpcGroup($fillProperties = false)
  {
    $object = new GhRpcGroupslibRpcGroup();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_groupslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcGroupslibRpcGroup extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * ParentRef
   * @var int
   */
  public $ParentRef;

  /**
   * CategoryRefs
   * @var array
   */
  public $CategoryRefs;

  /**
   * UserRefs
   * @var array
   */
  public $UserRefs;

  /**
   * Signatures
   * @var GhRpcGroupslibRpcGroupSignatures
   */
  public $Signatures;

  /**
   * Order
   * @var int
   */
  public $Order;

  /**
   * WorkSpace
   * @var int
   */
  public $WorkSpace;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Path
   * @var string
   */
  public $Path;

  /**
   * Email
   * @var string
   */
  public $Email;

  /**
   * Phone
   * @var string
   */
  public $Phone;

  /**
   * Fax
   * @var string
   */
  public $Fax;

  /**
   * Mobile
   * @var string
   */
  public $Mobile;

  /**
   * PostalAddress
   * @var string
   */
  public $PostalAddress;

  /**
   * Message
   * @var string
   */
  public $Message;

  /**
   * ForceTopic
   * @var boolean
   */
  public $ForceTopic;

  /**
   * LockData
   * @var GhRpcGroupslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'ParentRef' => 'int',
    'CategoryRefs' => 'array:int',
    'UserRefs' => 'array:int',
    'Signatures' => 'GhRpcGroupslibRpcGroupSignatures',
    'Order' => 'int',
    'WorkSpace' => 'int',
    'Name' => 'string',
    'Path' => 'string',
    'Email' => 'string',
    'Phone' => 'string',
    'Fax' => 'string',
    'Mobile' => 'string',
    'PostalAddress' => 'string',
    'Message' => 'string',
    'ForceTopic' => 'boolean',
    'LockData' => 'GhRpcGroupslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_groupslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcGroupslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_groupslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcGroupslibRpcGroupSignatures extends GhRpcStruct
{
  /**
   * EmailSignatureRef
   * @var int
   */
  public $EmailSignatureRef;

  /**
   * FaxSignatureRef
   * @var int
   */
  public $FaxSignatureRef;

  /**
   * LetterSignatureRef
   * @var int
   */
  public $LetterSignatureRef;

  /**
   * MessageSignatureRef
   * @var int
   */
  public $MessageSignatureRef;

  /**
   * CallSignatureRef
   * @var int
   */
  public $CallSignatureRef;

  /**
   * AppointmentSignatureRef
   * @var int
   */
  public $AppointmentSignatureRef;

  /**
   * TaskSignatureRef
   * @var int
   */
  public $TaskSignatureRef;

  /**
   * NoteSignatureRef
   * @var int
   */
  public $NoteSignatureRef;

  /**
   * ContactSignatureRef
   * @var int
   */
  public $ContactSignatureRef;

  /**
   * FileSignatureRef
   * @var int
   */
  public $FileSignatureRef;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'EmailSignatureRef' => 'int',
    'FaxSignatureRef' => 'int',
    'LetterSignatureRef' => 'int',
    'MessageSignatureRef' => 'int',
    'CallSignatureRef' => 'int',
    'AppointmentSignatureRef' => 'int',
    'TaskSignatureRef' => 'int',
    'NoteSignatureRef' => 'int',
    'ContactSignatureRef' => 'int',
    'FileSignatureRef' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcGroups
 *
 * @package GhRpc
 * @subpackage rpc_groupslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcGroupslibRpcGroups extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcGroupslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'SetOrder' => array(
      'params' => array(
        'ID' => 'int',
        'Order' => 'int',
      ),
      'return' => '',
    ),
    'AddUser' => array(
      'params' => array(
        'ID' => 'int',
        'UserRef' => 'int',
      ),
      'return' => '',
    ),
    'AddCategory' => array(
      'params' => array(
        'ID' => 'int',
        'CategoryRef' => 'int',
      ),
      'return' => '',
    ),
    'SetParent' => array(
      'params' => array(
        'ID' => 'int',
        'ParentRef' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Group' => 'GhRpcGroupslibRpcGroup',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Group' => 'GhRpcGroupslibRpcGroup',
      ),
      'return' => 'int',
    ),
    'GetCompleteList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcGroupslibRpcGroup',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcGroupslibRpcGroup',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcGroupslibRpcGroup',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcGroups.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcGroupslibRpcGroup
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcGroups.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.GetCompleteList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetCompleteList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcGroups.GetCompleteList', array($AdvancedFields), self::$_rpcMethods['GetCompleteList']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcGroupslibRpcGroup $Group
   *
   * @return int
   */
  public function New_(GhRpcGroupslibRpcGroup $Group = null)
  {
    return $this->_sendRpcRequest('RpcGroups.New', array($Group), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcGroupslibRpcGroup $Group
   */
  public function Put(GhRpcGroupslibRpcGroup $Group = null)
  {
    return $this->_sendRpcRequest('RpcGroups.Put', array($Group), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.SetParent auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $ParentRef
   */
  public function SetParent($ID = 0, $ParentRef = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.SetParent', array($ID, $ParentRef), self::$_rpcMethods['SetParent']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.AddCategory auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $CategoryRef
   */
  public function AddCategory($ID = 0, $CategoryRef = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.AddCategory', array($ID, $CategoryRef), self::$_rpcMethods['AddCategory']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.AddUser auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $UserRef
   */
  public function AddUser($ID = 0, $UserRef = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.AddUser', array($ID, $UserRef), self::$_rpcMethods['AddUser']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.SetOrder auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Order
   */
  public function SetOrder($ID = 0, $Order = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.SetOrder', array($ID, $Order), self::$_rpcMethods['SetOrder']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcGroups.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcGroupslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcGroups.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
