<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_memorylib.
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_memorylib extends GhRpcLibrary
{
  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcMemory.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcMemorylibRpcMemory
   */
  public static function newRpcMemory(GhRpcClient $client)
  {
    return new GhRpcMemorylibRpcMemory($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcStringValue.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMemorylibRpcStringValue
   */
  public static function newRpcStringValue($fillProperties = false)
  {
    $object = new GhRpcMemorylibRpcStringValue();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcBooleanValue.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMemorylibRpcBooleanValue
   */
  public static function newRpcBooleanValue($fillProperties = false)
  {
    $object = new GhRpcMemorylibRpcBooleanValue();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDoubleValue.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMemorylibRpcDoubleValue
   */
  public static function newRpcDoubleValue($fillProperties = false)
  {
    $object = new GhRpcMemorylibRpcDoubleValue();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcInt64Value.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMemorylibRpcInt64Value
   */
  public static function newRpcInt64Value($fillProperties = false)
  {
    $object = new GhRpcMemorylibRpcInt64Value();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcIntegerValue.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMemorylibRpcIntegerValue
   */
  public static function newRpcIntegerValue($fillProperties = false)
  {
    $object = new GhRpcMemorylibRpcIntegerValue();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcStringArray.
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMemorylibRpcIntegerValue extends GhRpcStruct
{
  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * Value
   * @var int
   */
  public $Value;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Key' => 'string',
    'Value' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcStringArray.
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMemorylibRpcInt64Value extends GhRpcStruct
{
  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * Value
   * @var GhRpcInt64
   */
  public $Value;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Key' => 'string',
    'Value' => 'GhRpcInt64',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcStringArray.
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMemorylibRpcDoubleValue extends GhRpcStruct
{
  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * Value
   * @var double
   */
  public $Value;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Key' => 'string',
    'Value' => 'double',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcStringArray.
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMemorylibRpcBooleanValue extends GhRpcStruct
{
  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * Value
   * @var boolean
   */
  public $Value;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Key' => 'string',
    'Value' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcStringArray.
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMemorylibRpcStringValue extends GhRpcStruct
{
  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * Value
   * @var string
   */
  public $Value;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Key' => 'string',
    'Value' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcMemory
 *
 * @package GhRpc
 * @subpackage rpc_memorylib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMemorylibRpcMemory extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetStringList' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Offset' => 'int',
        'Limit' => 'int',
      ),
      'return' => 'array:GhRpcMemorylibRpcStringValue',
    ),
    'GetBooleanList' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Offset' => 'int',
        'Limit' => 'int',
      ),
      'return' => 'array:GhRpcMemorylibRpcBooleanValue',
    ),
    'GetDoubleList' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Offset' => 'int',
        'Limit' => 'int',
      ),
      'return' => 'array:GhRpcMemorylibRpcDoubleValue',
    ),
    'GetInt64List' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Offset' => 'int',
        'Limit' => 'int',
      ),
      'return' => 'array:GhRpcMemorylibRpcInt64Value',
    ),
    'GetIntegerList' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Offset' => 'int',
        'Limit' => 'int',
      ),
      'return' => 'array:GhRpcMemorylibRpcIntegerValue',
    ),
    'SetUpdateExpireOnAccess' => array(
      'params' => array(
        'Namespace' => 'string',
        'Value' => 'boolean',
      ),
      'return' => '',
    ),
    'GetUpdateExpireOnAccess' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => 'boolean',
    ),
    'SetMaxSize' => array(
      'params' => array(
        'Namespace' => 'string',
        'Value' => 'int',
      ),
      'return' => '',
    ),
    'GetMaxSize' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => 'int',
    ),
    'GetSize' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => 'int',
    ),
    'GetCount' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => 'int',
    ),
    'Decrement' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'int',
      ),
      'return' => 'int',
    ),
    'Increment' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'int',
      ),
      'return' => 'int',
    ),
    'Clear' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => '',
    ),
    'DeleteKeyStarts' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => '',
    ),
    'ExistsKeyStarts' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'boolean',
    ),
    'Exists' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'boolean',
    ),
    'PutString' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'string',
        'Expire' => 'int',
      ),
      'return' => '',
    ),
    'PutBoolean' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'boolean',
        'Expire' => 'int',
      ),
      'return' => '',
    ),
    'PutDouble' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'double',
        'Expire' => 'int',
      ),
      'return' => '',
    ),
    'PutInt64' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'GhRpcInt64',
        'Expire' => 'int',
      ),
      'return' => '',
    ),
    'PutInteger' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'int',
        'Expire' => 'int',
      ),
      'return' => '',
    ),
    'GetString' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'string',
    ),
    'GetBoolean' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'boolean',
    ),
    'GetDouble' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'double',
    ),
    'GetInt64' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'GhRpcInt64',
    ),
    'GetInteger' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
      ),
      'return' => 'int',
    ),
    'AddString' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'string',
        'Expire' => 'int',
      ),
      'return' => 'boolean',
    ),
    'AddBoolean' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'boolean',
        'Expire' => 'int',
      ),
      'return' => 'boolean',
    ),
    'AddDouble' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'double',
        'Expire' => 'int',
      ),
      'return' => 'boolean',
    ),
    'AddInt64' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'GhRpcInt64',
        'Expire' => 'int',
      ),
      'return' => 'boolean',
    ),
    'AddInteger' => array(
      'params' => array(
        'Namespace' => 'string',
        'Key' => 'string',
        'Value' => 'int',
        'Expire' => 'int',
      ),
      'return' => 'boolean',
    ),
    'Unlock' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'Namespace' => 'string',
      ),
      'return' => 'boolean',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcMemory.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   *
   * @return boolean
   */
  public function Lock($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.Lock', array($Namespace), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   */
  public function Unlock($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.Unlock', array($Namespace), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.AddInteger auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Value
   * @param int $Expire
   *
   * @return boolean
   */
  public function AddInteger($Namespace = '', $Key = '', $Value = 0, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.AddInteger', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['AddInteger']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.AddInt64 auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param GhRpcInt64 $Value
   * @param int $Expire
   *
   * @return boolean
   */
  public function AddInt64($Namespace = '', $Key = '', GhRpcInt64 $Value = null, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.AddInt64', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['AddInt64']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.AddDouble auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param double $Value
   * @param int $Expire
   *
   * @return boolean
   */
  public function AddDouble($Namespace = '', $Key = '', $Value = 0, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.AddDouble', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['AddDouble']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.AddBoolean auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param boolean $Value
   * @param int $Expire
   *
   * @return boolean
   */
  public function AddBoolean($Namespace = '', $Key = '', $Value = false, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.AddBoolean', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['AddBoolean']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.AddString auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param string $Value
   * @param int $Expire
   *
   * @return boolean
   */
  public function AddString($Namespace = '', $Key = '', $Value = '', $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.AddString', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['AddString']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetInteger auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return int
   */
  public function GetInteger($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetInteger', array($Namespace, $Key), self::$_rpcMethods['GetInteger']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetInt64 auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return GhRpcInt64
   */
  public function GetInt64($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetInt64', array($Namespace, $Key), self::$_rpcMethods['GetInt64']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetDouble auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return double
   */
  public function GetDouble($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetDouble', array($Namespace, $Key), self::$_rpcMethods['GetDouble']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetBoolean auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return boolean
   */
  public function GetBoolean($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetBoolean', array($Namespace, $Key), self::$_rpcMethods['GetBoolean']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetString auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return string
   */
  public function GetString($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetString', array($Namespace, $Key), self::$_rpcMethods['GetString']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.PutInteger auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Value
   * @param int $Expire
   */
  public function PutInteger($Namespace = '', $Key = '', $Value = 0, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.PutInteger', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['PutInteger']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.PutInt64 auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param GhRpcInt64 $Value
   * @param int $Expire
   */
  public function PutInt64($Namespace = '', $Key = '', GhRpcInt64 $Value = null, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.PutInt64', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['PutInt64']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.PutDouble auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param double $Value
   * @param int $Expire
   */
  public function PutDouble($Namespace = '', $Key = '', $Value = 0, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.PutDouble', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['PutDouble']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.PutBoolean auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param boolean $Value
   * @param int $Expire
   */
  public function PutBoolean($Namespace = '', $Key = '', $Value = false, $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.PutBoolean', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['PutBoolean']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.PutString auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param string $Value
   * @param int $Expire
   */
  public function PutString($Namespace = '', $Key = '', $Value = '', $Expire = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.PutString', array($Namespace, $Key, $Value, $Expire), self::$_rpcMethods['PutString']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.Exists auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return boolean
   */
  public function Exists($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.Exists', array($Namespace, $Key), self::$_rpcMethods['Exists']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.ExistsKeyStarts auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   *
   * @return boolean
   */
  public function ExistsKeyStarts($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.ExistsKeyStarts', array($Namespace, $Key), self::$_rpcMethods['ExistsKeyStarts']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   */
  public function Delete($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.Delete', array($Namespace, $Key), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.DeleteKeyStarts auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   */
  public function DeleteKeyStarts($Namespace = '', $Key = '')
  {
    return $this->_sendRpcRequest('RpcMemory.DeleteKeyStarts', array($Namespace, $Key), self::$_rpcMethods['DeleteKeyStarts']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.Clear auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   */
  public function Clear($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.Clear', array($Namespace), self::$_rpcMethods['Clear']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.Increment auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Value
   *
   * @return int
   */
  public function Increment($Namespace = '', $Key = '', $Value = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.Increment', array($Namespace, $Key, $Value), self::$_rpcMethods['Increment']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.Decrement auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Value
   *
   * @return int
   */
  public function Decrement($Namespace = '', $Key = '', $Value = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.Decrement', array($Namespace, $Key, $Value), self::$_rpcMethods['Decrement']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetCount auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   *
   * @return int
   */
  public function GetCount($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetCount', array($Namespace), self::$_rpcMethods['GetCount']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetSize auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   *
   * @return int
   */
  public function GetSize($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetSize', array($Namespace), self::$_rpcMethods['GetSize']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetMaxSize auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   *
   * @return int
   */
  public function GetMaxSize($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetMaxSize', array($Namespace), self::$_rpcMethods['GetMaxSize']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.SetMaxSize auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param int $Value
   */
  public function SetMaxSize($Namespace = '', $Value = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.SetMaxSize', array($Namespace, $Value), self::$_rpcMethods['SetMaxSize']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetUpdateExpireOnAccess auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   *
   * @return boolean
   */
  public function GetUpdateExpireOnAccess($Namespace = '')
  {
    return $this->_sendRpcRequest('RpcMemory.GetUpdateExpireOnAccess', array($Namespace), self::$_rpcMethods['GetUpdateExpireOnAccess']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.SetUpdateExpireOnAccess auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param boolean $Value
   */
  public function SetUpdateExpireOnAccess($Namespace = '', $Value = false)
  {
    return $this->_sendRpcRequest('RpcMemory.SetUpdateExpireOnAccess', array($Namespace, $Value), self::$_rpcMethods['SetUpdateExpireOnAccess']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetIntegerList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Offset
   * @param int $Limit
   *
   * @return array
   */
  public function GetIntegerList($Namespace = '', $Key = '', $Offset = 0, $Limit = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.GetIntegerList', array($Namespace, $Key, $Offset, $Limit), self::$_rpcMethods['GetIntegerList']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetInt64List auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Offset
   * @param int $Limit
   *
   * @return array
   */
  public function GetInt64List($Namespace = '', $Key = '', $Offset = 0, $Limit = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.GetInt64List', array($Namespace, $Key, $Offset, $Limit), self::$_rpcMethods['GetInt64List']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetDoubleList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Offset
   * @param int $Limit
   *
   * @return array
   */
  public function GetDoubleList($Namespace = '', $Key = '', $Offset = 0, $Limit = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.GetDoubleList', array($Namespace, $Key, $Offset, $Limit), self::$_rpcMethods['GetDoubleList']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetBooleanList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Offset
   * @param int $Limit
   *
   * @return array
   */
  public function GetBooleanList($Namespace = '', $Key = '', $Offset = 0, $Limit = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.GetBooleanList', array($Namespace, $Key, $Offset, $Limit), self::$_rpcMethods['GetBooleanList']);
  }

  /**
   * Ruft die RPC-Funktion RpcMemory.GetStringList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Namespace
   * @param string $Key
   * @param int $Offset
   * @param int $Limit
   *
   * @return array
   */
  public function GetStringList($Namespace = '', $Key = '', $Offset = 0, $Limit = 0)
  {
    return $this->_sendRpcRequest('RpcMemory.GetStringList', array($Namespace, $Key, $Offset, $Limit), self::$_rpcMethods['GetStringList']);
  }
}
