<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_mimetypeslib.
 *
 * @package GhRpc
 * @subpackage rpc_mimetypeslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_mimetypeslib extends GhRpcLibrary
{
  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcMimetypes.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcMimetypeslibRpcMimetypes
   */
  public static function newRpcMimetypes(GhRpcClient $client)
  {
    return new GhRpcMimetypeslibRpcMimetypes($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMimetypeslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcMimetypeslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMimetype.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMimetypeslibRpcMimetype
   */
  public static function newRpcMimetype($fillProperties = false)
  {
    $object = new GhRpcMimetypeslibRpcMimetype();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcMimetypeList.
 *
 * @package GhRpc
 * @subpackage rpc_mimetypeslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMimetypeslibRpcMimetype extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Mimetype
   * @var string
   */
  public $Mimetype;

  /**
   * Extensions
   * @var array
   */
  public $Extensions;

  /**
   * LockData
   * @var GhRpcMimetypeslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Mimetype' => 'string',
    'Extensions' => 'array:string',
    'LockData' => 'GhRpcMimetypeslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcMimetypeList.
 *
 * @package GhRpc
 * @subpackage rpc_mimetypeslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMimetypeslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcMimetypes
 *
 * @package GhRpc
 * @subpackage rpc_mimetypeslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMimetypeslibRpcMimetypes extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMimetypeslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Mimetype' => 'GhRpcMimetypeslibRpcMimetype',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Mimetype' => 'GhRpcMimetypeslibRpcMimetype',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcMimetypeslibRpcMimetype',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMimetypeslibRpcMimetype',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcMimetypes.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMimetypeslibRpcMimetype
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMimetypes.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcMimetypes.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcMimetypeslibRpcMimetype $Mimetype
   *
   * @return int
   */
  public function New_(GhRpcMimetypeslibRpcMimetype $Mimetype = null)
  {
    return $this->_sendRpcRequest('RpcMimetypes.New', array($Mimetype), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcMimetypeslibRpcMimetype $Mimetype
   */
  public function Put(GhRpcMimetypeslibRpcMimetype $Mimetype = null)
  {
    return $this->_sendRpcRequest('RpcMimetypes.Put', array($Mimetype), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMimetypes.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMimetypes.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMimetypes.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMimetypes.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMimetypeslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMimetypes.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
