<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_salutationslib.
 *
 * @package GhRpc
 * @subpackage rpc_salutationslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_salutationslib extends GhRpcLibrary
{
  // RpcSalutationAffix Konstanten:

  /**
   * saTitle Konstante (gehört zum Enum: RpcSalutationAffix).
   */
  const saTitle = 0;
  /**
   * saFirstname Konstante (gehört zum Enum: RpcSalutationAffix).
   */
  const saFirstname = 1;
  /**
   * saSecondname Konstante (gehört zum Enum: RpcSalutationAffix).
   */
  const saSecondname = 2;
  /**
   * saLastname Konstante (gehört zum Enum: RpcSalutationAffix).
   */
  const saLastname = 3;
  /**
   * saCallname Konstante (gehört zum Enum: RpcSalutationAffix).
   */
  const saCallname = 4;
  /**
   * saCompany Konstante (gehört zum Enum: RpcSalutationAffix).
   */
  const saCompany = 5;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcSalutationSex Konstanten:

  /**
   * ssNeutral Konstante (gehört zum Enum: RpcSalutationSex).
   */
  const ssNeutral = 0;
  /**
   * ssMale Konstante (gehört zum Enum: RpcSalutationSex).
   */
  const ssMale = 1;
  /**
   * ssFemale Konstante (gehört zum Enum: RpcSalutationSex).
   */
  const ssFemale = 2;
  /**
   * ssDiverse Konstante (gehört zum Enum: RpcSalutationSex).
   */
  const ssDiverse = 3;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcSalutations.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcSalutationslibRpcSalutations
   */
  public static function newRpcSalutations(GhRpcClient $client)
  {
    return new GhRpcSalutationslibRpcSalutations($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSalutationslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcSalutationslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcSalutation.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSalutationslibRpcSalutation
   */
  public static function newRpcSalutation($fillProperties = false)
  {
    $object = new GhRpcSalutationslibRpcSalutation();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcSalutationList.
 *
 * @package GhRpc
 * @subpackage rpc_salutationslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSalutationslibRpcSalutation extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Sex
   * @var int
   */
  public $Sex;

  /**
   * Salutation
   * @var string
   */
  public $Salutation;

  /**
   * Affixes
   * @var int
   */
  public $Affixes;

  /**
   * LockData
   * @var GhRpcSalutationslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Sex' => 'int',
    'Salutation' => 'string',
    'Affixes' => 'int',
    'LockData' => 'GhRpcSalutationslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcSalutationList.
 *
 * @package GhRpc
 * @subpackage rpc_salutationslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSalutationslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcSalutations
 *
 * @package GhRpc
 * @subpackage rpc_salutationslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSalutationslibRpcSalutations extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcSalutationslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Salutation' => 'GhRpcSalutationslibRpcSalutation',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Salutation' => 'GhRpcSalutationslibRpcSalutation',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
        'Sexes' => 'int',
      ),
      'return' => 'array:GhRpcSalutationslibRpcSalutation',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcSalutationslibRpcSalutation',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcSalutations.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcSalutationslibRpcSalutation
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSalutations.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $Sexes
   *
   * @return array
   */
  public function GetList($Sexes = 0)
  {
    return $this->_sendRpcRequest('RpcSalutations.GetList', array($Sexes), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSalutationslibRpcSalutation $Salutation
   *
   * @return int
   */
  public function New_(GhRpcSalutationslibRpcSalutation $Salutation = null)
  {
    return $this->_sendRpcRequest('RpcSalutations.New', array($Salutation), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSalutationslibRpcSalutation $Salutation
   */
  public function Put(GhRpcSalutationslibRpcSalutation $Salutation = null)
  {
    return $this->_sendRpcRequest('RpcSalutations.Put', array($Salutation), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSalutations.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSalutations.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSalutations.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcSalutations.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcSalutationslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSalutations.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
