<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2022 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_signatureslib.
 *
 * @package GhRpc
 * @subpackage rpc_signatureslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_signatureslib extends GhRpcLibrary
{
  // RpcSignatureKind Konstanten:

  /**
   * skEmail Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skEmail = 0;
  /**
   * skFax Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skFax = 1;
  /**
   * skLetter Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skLetter = 2;
  /**
   * skMessage Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skMessage = 3;
  /**
   * skCall Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skCall = 4;
  /**
   * skAppointment Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skAppointment = 5;
  /**
   * skTask Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skTask = 6;
  /**
   * skNote Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skNote = 7;
  /**
   * skContact Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skContact = 8;
  /**
   * skFile Konstante (gehört zum Enum: RpcSignatureKind).
   */
  const skFile = 9;

  // RpcSynchronisation Konstanten:

  /**
   * sNo Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sNo = 0;
  /**
   * sHtml Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sHtml = 1;
  /**
   * sText Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sText = 2;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 1;
  /**
   * wsShared Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsShared = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcSignatures.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcSignatureslibRpcSignatures
   */
  public static function newRpcSignatures(GhRpcClient $client)
  {
    return new GhRpcSignatureslibRpcSignatures($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcSignatureGroup.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSignatureslibRpcSignatureGroup
   */
  public static function newRpcSignatureGroup($fillProperties = false)
  {
    $object = new GhRpcSignatureslibRpcSignatureGroup();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSignatureslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcSignatureslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcSignature.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSignatureslibRpcSignature
   */
  public static function newRpcSignature($fillProperties = false)
  {
    $object = new GhRpcSignatureslibRpcSignature();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcSignatureGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_signatureslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSignatureslibRpcSignature extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Kinds
   * @var int
   */
  public $Kinds;

  /**
   * Groups
   * @var array
   */
  public $Groups;

  /**
   * WorkSpace
   * @var int
   */
  public $WorkSpace;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * HtmlData
   * @var string
   */
  public $HtmlData;

  /**
   * TextData
   * @var string
   */
  public $TextData;

  /**
   * Synchronisation
   * @var int
   */
  public $Synchronisation;

  /**
   * LockData
   * @var GhRpcSignatureslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Kinds' => 'int',
    'Groups' => 'array:GhRpcSignatureslibRpcSignatureGroup',
    'WorkSpace' => 'int',
    'Name' => 'string',
    'HtmlData' => 'binary',
    'TextData' => 'string',
    'Synchronisation' => 'int',
    'LockData' => 'GhRpcSignatureslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcSignatureGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_signatureslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSignatureslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcSignatureGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_signatureslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSignatureslibRpcSignatureGroup extends GhRpcStruct
{
  /**
   * GroupRef
   * @var int
   */
  public $GroupRef;

  /**
   * DefaultKinds
   * @var int
   */
  public $DefaultKinds;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'GroupRef' => 'int',
    'DefaultKinds' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcSignatures
 *
 * @package GhRpc
 * @subpackage rpc_signatureslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSignatureslibRpcSignatures extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcSignatureslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Signature' => 'GhRpcSignatureslibRpcSignature',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Signature' => 'GhRpcSignatureslibRpcSignature',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcSignatureslibRpcSignature',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcSignatureslibRpcSignature',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcSignatures.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcSignatureslibRpcSignature
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSignatures.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcSignatures.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSignatureslibRpcSignature $Signature
   *
   * @return int
   */
  public function New_(GhRpcSignatureslibRpcSignature $Signature = null)
  {
    return $this->_sendRpcRequest('RpcSignatures.New', array($Signature), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSignatureslibRpcSignature $Signature
   */
  public function Put(GhRpcSignatureslibRpcSignature $Signature = null)
  {
    return $this->_sendRpcRequest('RpcSignatures.Put', array($Signature), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSignatures.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSignatures.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSignatures.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcSignatures.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcSignatureslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcSignatures.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
