<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2022 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_templateslib.
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_templateslib extends GhRpcLibrary
{
  // RpcSynchronisation Konstanten:

  /**
   * sNo Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sNo = 0;
  /**
   * sHtml Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sHtml = 1;
  /**
   * sText Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sText = 2;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcTemplatePreviewKind Konstanten:

  /**
   * tpkDif Konstante (gehört zum Enum: RpcTemplatePreviewKind).
   */
  const tpkDif = 0;
  /**
   * tpkBmp Konstante (gehört zum Enum: RpcTemplatePreviewKind).
   */
  const tpkBmp = 1;
  /**
   * tpkTiff Konstante (gehört zum Enum: RpcTemplatePreviewKind).
   */
  const tpkTiff = 2;
  /**
   * tpkPng Konstante (gehört zum Enum: RpcTemplatePreviewKind).
   */
  const tpkPng = 3;
  /**
   * tpkJpeg Konstante (gehört zum Enum: RpcTemplatePreviewKind).
   */
  const tpkJpeg = 4;

  // RpcTemplateKind Konstanten:

  /**
   * tkEmail Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkEmail = 0;
  /**
   * tkFax Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkFax = 1;
  /**
   * tkLetter Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkLetter = 2;
  /**
   * tkMessage Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkMessage = 3;
  /**
   * tkCall Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkCall = 4;
  /**
   * tkAppointment Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkAppointment = 5;
  /**
   * tkTask Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkTask = 6;
  /**
   * tkNote Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkNote = 7;
  /**
   * tkContact Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkContact = 8;
  /**
   * tkFile Konstante (gehört zum Enum: RpcTemplateKind).
   */
  const tkFile = 9;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcTemplates.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcTemplateslibRpcTemplates
   */
  public static function newRpcTemplates(GhRpcClient $client)
  {
    return new GhRpcTemplateslibRpcTemplates($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTemplateslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcTemplateslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcTemplateOptions.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTemplateslibRpcTemplateOptions
   */
  public static function newRpcTemplateOptions($fillProperties = false)
  {
    $object = new GhRpcTemplateslibRpcTemplateOptions();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcTemplateItem.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTemplateslibRpcTemplateItem
   */
  public static function newRpcTemplateItem($fillProperties = false)
  {
    $object = new GhRpcTemplateslibRpcTemplateItem();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcTemplateGroup.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTemplateslibRpcTemplateGroup
   */
  public static function newRpcTemplateGroup($fillProperties = false)
  {
    $object = new GhRpcTemplateslibRpcTemplateGroup();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcTemplate.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTemplateslibRpcTemplate
   */
  public static function newRpcTemplate($fillProperties = false)
  {
    $object = new GhRpcTemplateslibRpcTemplate();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcTemplateGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTemplateslibRpcTemplate extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Groups
   * @var array
   */
  public $Groups;

  /**
   * Kinds
   * @var int
   */
  public $Kinds;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * FontName
   * @var string
   */
  public $FontName;

  /**
   * FontSize
   * @var int
   */
  public $FontSize;

  /**
   * ParagraphSize
   * @var int
   */
  public $ParagraphSize;

  /**
   * FirstHtmlData
   * @var string
   */
  public $FirstHtmlData;

  /**
   * FirstTextData
   * @var string
   */
  public $FirstTextData;

  /**
   * FirstSynchronisation
   * @var int
   */
  public $FirstSynchronisation;

  /**
   * NextHtmlData
   * @var string
   */
  public $NextHtmlData;

  /**
   * NextTextData
   * @var string
   */
  public $NextTextData;

  /**
   * NextSynchronisation
   * @var int
   */
  public $NextSynchronisation;

  /**
   * ContentHtmlData
   * @var string
   */
  public $ContentHtmlData;

  /**
   * ContentTextData
   * @var string
   */
  public $ContentTextData;

  /**
   * ContentSynchronisation
   * @var int
   */
  public $ContentSynchronisation;

  /**
   * LockData
   * @var GhRpcTemplateslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Groups' => 'array:GhRpcTemplateslibRpcTemplateGroup',
    'Kinds' => 'int',
    'Name' => 'string',
    'FontName' => 'string',
    'FontSize' => 'int',
    'ParagraphSize' => 'int',
    'FirstHtmlData' => 'binary',
    'FirstTextData' => 'string',
    'FirstSynchronisation' => 'int',
    'NextHtmlData' => 'binary',
    'NextTextData' => 'string',
    'NextSynchronisation' => 'int',
    'ContentHtmlData' => 'binary',
    'ContentTextData' => 'string',
    'ContentSynchronisation' => 'int',
    'LockData' => 'GhRpcTemplateslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcTemplateGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTemplateslibRpcTemplateGroup extends GhRpcStruct
{
  /**
   * GroupRef
   * @var int
   */
  public $GroupRef;

  /**
   * DefaultKinds
   * @var int
   */
  public $DefaultKinds;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'GroupRef' => 'int',
    'DefaultKinds' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcTemplateGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTemplateslibRpcTemplateItem extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Kinds
   * @var int
   */
  public $Kinds;

  /**
   * Default
   * @var boolean
   */
  public $Default;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * FontName
   * @var string
   */
  public $FontName;

  /**
   * FontSize
   * @var int
   */
  public $FontSize;

  /**
   * ParagraphSize
   * @var int
   */
  public $ParagraphSize;

  /**
   * LockData
   * @var GhRpcTemplateslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Kinds' => 'int',
    'Default' => 'boolean',
    'Name' => 'string',
    'FontName' => 'string',
    'FontSize' => 'int',
    'ParagraphSize' => 'int',
    'LockData' => 'GhRpcTemplateslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcTemplateGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTemplateslibRpcTemplateOptions extends GhRpcStruct
{
  /**
   * Width
   * @var double
   */
  public $Width;

  /**
   * Height
   * @var double
   */
  public $Height;

  /**
   * MarginLeft
   * @var double
   */
  public $MarginLeft;

  /**
   * MarginTop
   * @var double
   */
  public $MarginTop;

  /**
   * MarginRight
   * @var double
   */
  public $MarginRight;

  /**
   * MarginBottom
   * @var double
   */
  public $MarginBottom;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Width' => 'double',
    'Height' => 'double',
    'MarginLeft' => 'double',
    'MarginTop' => 'double',
    'MarginRight' => 'double',
    'MarginBottom' => 'double',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcTemplateGroupList.
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTemplateslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcTemplates
 *
 * @package GhRpc
 * @subpackage rpc_templateslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTemplateslibRpcTemplates extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcTemplateslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Export' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'binary',
    ),
    'Import' => array(
      'params' => array(
        'XmlData' => 'binary',
      ),
      'return' => 'int',
    ),
    'SetDefault' => array(
      'params' => array(
        'ID' => 'int',
        'GroupRef' => 'int',
        'Kind' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Template' => 'GhRpcTemplateslibRpcTemplate',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Template' => 'GhRpcTemplateslibRpcTemplate',
      ),
      'return' => 'int',
    ),
    'GetDefault' => array(
      'params' => array(
        'Options' => 'GhRpcTemplateslibRpcTemplateOptions',
      ),
      'return' => 'GhRpcTemplateslibRpcTemplate',
    ),
    'GetPreview' => array(
      'params' => array(
        'ID' => 'int',
        'Kind' => 'int',
      ),
      'return' => 'binary',
    ),
    'GetCompleteList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcTemplateslibRpcTemplateItem',
    ),
    'GetList' => array(
      'params' => array(
        'GroupRef' => 'int',
        'Kind' => 'int',
      ),
      'return' => 'array:GhRpcTemplateslibRpcTemplateItem',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcTemplateslibRpcTemplate',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcTemplates.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcTemplateslibRpcTemplate
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $GroupRef
   * @param int $Kind
   *
   * @return array
   */
  public function GetList($GroupRef = 0, $Kind = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.GetList', array($GroupRef, $Kind), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.GetCompleteList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetCompleteList()
  {
    return $this->_sendRpcRequest('RpcTemplates.GetCompleteList', array(), self::$_rpcMethods['GetCompleteList']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.GetPreview auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Kind
   *
   * @return string
   */
  public function GetPreview($ID = 0, $Kind = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.GetPreview', array($ID, $Kind), self::$_rpcMethods['GetPreview']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.GetDefault auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcTemplateslibRpcTemplateOptions $Options
   *
   * @return GhRpcTemplateslibRpcTemplate
   */
  public function GetDefault(GhRpcTemplateslibRpcTemplateOptions $Options = null)
  {
    return $this->_sendRpcRequest('RpcTemplates.GetDefault', array($Options), self::$_rpcMethods['GetDefault']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcTemplateslibRpcTemplate $Template
   *
   * @return int
   */
  public function New_(GhRpcTemplateslibRpcTemplate $Template = null)
  {
    return $this->_sendRpcRequest('RpcTemplates.New', array($Template), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcTemplateslibRpcTemplate $Template
   */
  public function Put(GhRpcTemplateslibRpcTemplate $Template = null)
  {
    return $this->_sendRpcRequest('RpcTemplates.Put', array($Template), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.SetDefault auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $GroupRef
   * @param int $Kind
   */
  public function SetDefault($ID = 0, $GroupRef = 0, $Kind = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.SetDefault', array($ID, $GroupRef, $Kind), self::$_rpcMethods['SetDefault']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.Import auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $XmlData
   *
   * @return int
   */
  public function Import($XmlData = '')
  {
    return $this->_sendRpcRequest('RpcTemplates.Import', array($XmlData), self::$_rpcMethods['Import']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.Export auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return string
   */
  public function Export($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.Export', array($ID), self::$_rpcMethods['Export']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcTemplates.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcTemplateslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTemplates.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
