<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_textblockslib.
 *
 * @package GhRpc
 * @subpackage rpc_textblockslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_textblockslib extends GhRpcLibrary
{
  // RpcSynchronisation Konstanten:

  /**
   * sNo Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sNo = 0;
  /**
   * sHtml Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sHtml = 1;
  /**
   * sText Konstante (gehört zum Enum: RpcSynchronisation).
   */
  const sText = 2;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsForbidden Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsForbidden = 1;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 2;
  /**
   * wsForeign Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsForeign = 3;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcTextBlocks.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcTextblockslibRpcTextBlocks
   */
  public static function newRpcTextBlocks(GhRpcClient $client)
  {
    return new GhRpcTextblockslibRpcTextBlocks($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcPredictItem.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTextblockslibRpcPredictItem
   */
  public static function newRpcPredictItem($fillProperties = false)
  {
    $object = new GhRpcTextblockslibRpcPredictItem();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcVariableItem.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTextblockslibRpcVariableItem
   */
  public static function newRpcVariableItem($fillProperties = false)
  {
    $object = new GhRpcTextblockslibRpcVariableItem();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTextblockslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcTextblockslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcTextBlock.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcTextblockslibRpcTextBlock
   */
  public static function newRpcTextBlock($fillProperties = false)
  {
    $object = new GhRpcTextblockslibRpcTextBlock();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcPredictList.
 *
 * @package GhRpc
 * @subpackage rpc_textblockslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTextblockslibRpcTextBlock extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * ParentRef
   * @var int
   */
  public $ParentRef;

  /**
   * CategoryRefs
   * @var array
   */
  public $CategoryRefs;

  /**
   * WorkSpace
   * @var int
   */
  public $WorkSpace;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Path
   * @var string
   */
  public $Path;

  /**
   * KeyWords
   * @var string
   */
  public $KeyWords;

  /**
   * AutoText
   * @var string
   */
  public $AutoText;

  /**
   * ShortCut
   * @var string
   */
  public $ShortCut;

  /**
   * Subject
   * @var string
   */
  public $Subject;

  /**
   * HtmlData
   * @var string
   */
  public $HtmlData;

  /**
   * HtmlVariables
   * @var array
   */
  public $HtmlVariables;

  /**
   * TextData
   * @var string
   */
  public $TextData;

  /**
   * TextVariables
   * @var array
   */
  public $TextVariables;

  /**
   * Synchronisation
   * @var int
   */
  public $Synchronisation;

  /**
   * LockData
   * @var GhRpcTextblockslibRpcLockData
   */
  public $LockData;

  /**
   * UsedCount
   * @var int
   */
  public $UsedCount;

  /**
   * LastUsed
   * @var GhRpcDateTime
   */
  public $LastUsed;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'ParentRef' => 'int',
    'CategoryRefs' => 'array:int',
    'WorkSpace' => 'int',
    'Name' => 'string',
    'Path' => 'string',
    'KeyWords' => 'string',
    'AutoText' => 'string',
    'ShortCut' => 'string',
    'Subject' => 'string',
    'HtmlData' => 'binary',
    'HtmlVariables' => 'array:string',
    'TextData' => 'string',
    'TextVariables' => 'array:string',
    'Synchronisation' => 'int',
    'LockData' => 'GhRpcTextblockslibRpcLockData',
    'UsedCount' => 'int',
    'LastUsed' => 'GhRpcDateTime',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcPredictList.
 *
 * @package GhRpc
 * @subpackage rpc_textblockslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTextblockslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcPredictList.
 *
 * @package GhRpc
 * @subpackage rpc_textblockslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTextblockslibRpcVariableItem extends GhRpcStruct
{
  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Data
   * @var string
   */
  public $Data;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Name' => 'string',
    'Data' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcPredictList.
 *
 * @package GhRpc
 * @subpackage rpc_textblockslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTextblockslibRpcPredictItem extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Probability
   * @var double
   */
  public $Probability;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Probability' => 'double',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcTextBlocks
 *
 * @package GhRpc
 * @subpackage rpc_textblockslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcTextblockslibRpcTextBlocks extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'Predict' => array(
      'params' => array(
        'ItemRef' => 'int',
      ),
      'return' => 'array:GhRpcTextblockslibRpcPredictItem',
    ),
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcTextblockslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'AddCategory' => array(
      'params' => array(
        'ID' => 'int',
        'CategoryRef' => 'int',
      ),
      'return' => '',
    ),
    'SetParent' => array(
      'params' => array(
        'ID' => 'int',
        'ParentRef' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'TextBlock' => 'GhRpcTextblockslibRpcTextBlock',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'TextBlock' => 'GhRpcTextblockslibRpcTextBlock',
      ),
      'return' => 'int',
    ),
    'GetCompleteList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcTextblockslibRpcTextBlock',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcTextblockslibRpcTextBlock',
    ),
    'GetWithVariables' => array(
      'params' => array(
        'ID' => 'int',
        'MarkAsUsed' => 'boolean',
        'Variables' => 'array:GhRpcTextblockslibRpcVariableItem',
        'ItemRef' => 'int',
      ),
      'return' => 'GhRpcTextblockslibRpcTextBlock',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
        'MarkAsUsed' => 'boolean',
      ),
      'return' => 'GhRpcTextblockslibRpcTextBlock',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcTextBlocks.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param boolean $MarkAsUsed
   *
   * @return GhRpcTextblockslibRpcTextBlock
   */
  public function Get($ID = 0, $MarkAsUsed = false)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.Get', array($ID, $MarkAsUsed), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.GetWithVariables auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param boolean $MarkAsUsed
   * @param array $Variables
   * @param int $ItemRef
   *
   * @return GhRpcTextblockslibRpcTextBlock
   */
  public function GetWithVariables($ID = 0, $MarkAsUsed = false, array $Variables = array(), $ItemRef = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.GetWithVariables', array($ID, $MarkAsUsed, $Variables, $ItemRef), self::$_rpcMethods['GetWithVariables']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.GetCompleteList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetCompleteList($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.GetCompleteList', array($AdvancedFields), self::$_rpcMethods['GetCompleteList']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcTextblockslibRpcTextBlock $TextBlock
   *
   * @return int
   */
  public function New_(GhRpcTextblockslibRpcTextBlock $TextBlock = null)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.New', array($TextBlock), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcTextblockslibRpcTextBlock $TextBlock
   */
  public function Put(GhRpcTextblockslibRpcTextBlock $TextBlock = null)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.Put', array($TextBlock), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.SetParent auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $ParentRef
   */
  public function SetParent($ID = 0, $ParentRef = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.SetParent', array($ID, $ParentRef), self::$_rpcMethods['SetParent']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.AddCategory auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $CategoryRef
   */
  public function AddCategory($ID = 0, $CategoryRef = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.AddCategory', array($ID, $CategoryRef), self::$_rpcMethods['AddCategory']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcTextblockslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }

  /**
   * Ruft die RPC-Funktion RpcTextBlocks.Predict auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ItemRef
   *
   * @return array
   */
  public function Predict($ItemRef = 0)
  {
    return $this->_sendRpcRequest('RpcTextBlocks.Predict', array($ItemRef), self::$_rpcMethods['Predict']);
  }
}
