/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2013 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

dojo.provide("greyhound.dojo.Dialog");

dojo.require("dijit.Dialog");

/**
 * Dialog-Komponente.
 *
 * Diese Komponente ist identisch zum dijit.Dialog, nimmt jedoch Korrekturen
 * an der Dialoghöhe vor.
 */
dojo.declare("greyhound.dojo.Dialog", [dijit.Dialog],
{
  ghHeight: null,
  ghDialogContent: null,
  ghDialogActionBar: null,

  /**
   * Diese Methode wird überladen um die Höhe des Dialogs bzw. seiner Inhalte
   * zu korrigieren.
   */
  _size: function()
  {
    this.inherited(arguments);

    this.ghUpdateSize();
  },

  /**
   * Passt die Höhe des Dialogs erneut an die Inhalte an.
   */
  ghUpdateSize: function()
  {
    // Höhe des Dialogs bzw. der Dialoginhalte anpassen:
    if(this.ghHeight)
    {
      var dialogSize = dojo.contentBox(this.domNode);
      var titleSize = dojo.marginBox(this.titleBar);
      var actionSize = dojo.marginBox(this.ghDialogActionBar.domNode);
      var contentSize = dojo.marginBox(this.ghDialogContent.domNode);
      var contentInnerSize = dojo.contentBox(this.ghDialogContent.domNode);

      // Höhe der Container-Node auf die Dialoghöhe hochsetzen:
      this.containerNode.style.height = (dialogSize.h - titleSize.h) + "px";

      // Höhe des Inhaltsbereichs auf die Container-Node-Höhe (minus der Höhe der Action-Bar) hochsetzen:
      this.ghDialogContent.domNode.style.height = (dialogSize.h - titleSize.h - actionSize.h - contentSize.h + contentInnerSize.h) + "px";
    }
    else
    {
      var actionSize = dojo.marginBox(this.ghDialogActionBar.domNode);
      var contentSize = dojo.marginBox(this.ghDialogContent.domNode);

      // Höhe der Container-Node auf die Höhe der Inhalte (Inhaltsbereich und Action-Bar) hochsetzen:
      this.containerNode.style.height = (actionSize.h + contentSize.h) + "px";
    }
  }
});
